@@ -16,14 +16,25 @@
 % if x is a 3 x 3 x 4 array, and we all operation along
 % dimension d=2, then the output is of size 3 x 1 x 4.
 
-% Copyright (c) 2002-2006 Samit Basu
+% Copyright (c) 2002-2007 Samit Basu
+% Licensed under the GPL
 
 function y = all(A,dim)
   if (nargin == 0)
     error 'all function requires at least one argument'
   end
   if (nargin == 1)
-    y = min(logical(A(:)));
-  else
-    y = min(logical(A),dim);
+     if  ~isempty(A) 
+        y = min(logical(A));
+     else
+        y = 1;
+     end
+     else
+       if ~isempty(A)
+          y = min(logical(A),[],dim);
+       else
+          v=size(A);
+          v(dim)=1;
+          y=ones(v);
+       end
   end
