@@ -16,14 +16,22 @@
 % if x is a 3 x 3 x 4 array, and we any operation along
 % dimension d=2, then the output is of size 3 x 1 x 4.
 
-% Copyright (c) 2002-2006 Samit Basu
+% Copyright (c) 2002-2007 Samit Basu
+% Licensed under the GPL
 
 function y = any(A,dim)
   if (nargin == 0)
     error 'any function requires at least one argument'
   end
+  A(find(isnan(A)))=0;
   if (nargin == 1)
-    y = max(logical(A(:)));
-  else
-    y = max(logical(A),[],dim);
+    y = max(logical(A));
+ else
+    if ~isempty( A )
+       y = max(logical(A),[],dim);
+    else
+       v=size(A);
+       v(dim)=1;
+       y=zeros(v);
+    end
   end
